%global _hardened_build 1

# Make reproducible builds possible
%global source_date_epoch_from_changelog 0
%global clamp_mtime_to_source_date_epoch 1
%global use_source_date_epoch_as_buildtime 1
%define _buildhost apkg

%global systemctl_bin /usr/bin/systemctl
%global selinuxtype targeted
%global with_selinux 0
%if 0%{?centos_ver} && 0%{?centos_ver} >= 8
%global with_selinux 1
%endif

%{!?_syprefix: %define _syprefix /opt/symas }
%{!?_etcfix: %define _etcfix %{_syprefix}/etc }
%{!?_sylibdir: %define _sylibdir %{_syprefix}/lib }
%{!?_varfix: %define _varfix /var/symas }

%if 0%{?suse_version}
# We don't seem to have %{dist} in SUSEs, define our own
%{!?dist: %define dist .sles15 }
%endif

Summary: Symas's OpenLDAP build
Name: symas-openldap
Version: 2.6.10
Release: 1+znssl1%{?dist}
License: BSD
# Apparently distro setup should fill this in, but can't see where,
# Fake ours from dist and strip the leading dot
Distribution: %(echo %{?dist} | tr -d .)

URL: https://www.openldap.org
VCS: https://git.symas.net/symas-public/openldap.git

# One at a time, microdnf doesn't support comma separated dependencies
BuildRequires: symas-buildtools >= 1.0.4
%if 0%{?suse_version}
BuildRequires: libopenssl-devel
%else
BuildRequires: openssl-devel
%endif
BuildRequires: symas-cyrus-sasl-devel
BuildRequires: gcc
BuildRequires: make
BuildRequires: groff
BuildRequires: libtool-ltdl-devel
BuildRequires: symas-heimdal-devel
BuildRequires: symas-libargon2-devel
BuildRequires: symas-libevent-devel
BuildRequires: cracklib-devel
BuildRequires: systemd-devel


# Do not try and automatically determine dependencies
AutoReqProv: No

Source0: %{name}-v%{version}.tar.xz
Source1: extras.tar.xz
Source2: symas-openldap-servers.service
Source3: symas-openldap-servers-tmpfiles.conf

# Patch0 and Patch1 are always required for 2.5
Patch0: Install-slapd-watcher.patch
Patch1: passwd.patch
# Any post-release specific patches should start here

%description
Symas's OpenLDAP 2.6 build

# Library package information
%package libs
Summary: openldap Libaries
Requires: openssl
Requires: symas-cyrus-sasl-libs
AutoReqProv: no

%description libs
The symas-openldap-libs package contains the openldap libraries

# Devel package information
%package devel
Summary: openldap Development
Requires: symas-openldap-libs = %{version}-%{release}
AutoReqProv: no

%description devel
The symas-openldap-devel package contains the linking libraries and include files

# Server package information
%package servers
Summary: openldap server binaries
Requires: symas-openldap-libs = %{version}-%{release}
Requires: symas-libargon2-libs
Requires: symas-heimdal-libs
Requires: cracklib >= 2.9.6
Requires: symas-libevent-libs
%if 0%{?suse_version}
Requires: libltdl7
%else
Requires: libtool-ltdl
%endif
%if 0%{?with_selinux}
# This ensures that the *-selinux package and all it’s dependencies are not pulled
# into containers and other systems that do not use SELinux
Requires: (symas-openldap-servers-selinux if selinux-policy-%{selinuxtype})
%endif
Provides: openldap-servers
Provides: symas-openldap-module-abi = 2.6
Conflicts: openldap-servers
AutoReqProv: no

%description servers
The symas-openldap-servers package contains slapd and its modules

# Client package information
%package clients
Summary: openldap client binaries
Requires: symas-openldap-libs = %{version}-%{release}
AutoReqProv: no

%description clients
The symas-openldap-clients package contains client tools such as ldapsearch

# Moddev is a special package put together by Symas for making it possible
# to build 3rd party modules such as pw-bcrypt that require headers
# specific to the build process that are not included in the devel package
%package moddev
Summary: OpenLDAP module development pieces
Requires: symas-openldap-devel = %{version}-%{release}
Provides: symas-openldap-api-dev = 2.6
AutoReqProv: no

%description moddev
This package allows development of slapd overlays and modules using the
OpenlDAP libraries. It includes module specific headers and the libtool
utility required for compilation.

# Extract the source(s) and apply patches
%prep
%setup -qn %{name}-v%{version}
%setup -qcDT -a 1 -n %{name}-v%{version}/extras
# switch back to the main directory
# FIXME: is there something missing in the %setup above?
%setup -qDTn %{name}-v%{version}

# Patch0 and patch1 are mandatory
%patch0 -p1
%patch1 -p1
# Any additional post-release patches start here

# Build the software
%build
%if 0%{?suse_version}
export LDFLAGS="-Wl,--disable-new-dtags -L%{_sylibdir} -Wl,-rpath,%{_sylibdir}"
%else
export LDFLAGS="%{__global_ldflags} -L%{_sylibdir} -Wl,-rpath,%{_sylibdir}"
%endif
export CFLAGS="%{optflags} -fPIC"
export CPPFLAGS=-I%{_syprefix}/include
./configure --prefix=%{_syprefix} \
    --with-cyrus-sasl \
    --with-tls=openssl \
    --libexecdir=%{_sylibdir} \
    --datadir=%{_varfix} \
    --sysconfdir=%{_etcfix} \
    --sharedstatedir=%{_etcfix} \
    --localstatedir=%{_varfix} \
    --enable-dynamic \
    --enable-slapd \
    --enable-modules \
    --enable-dynacl \
    --enable-balancer=mod \
    --enable-backends=mod \
        --disable-sql \
        --disable-perl \
        --disable-wt \
    --enable-overlays=mod \
        --disable-seqmod \
    --enable-argon2 \
    --enable-debug \
    --enable-spasswd \
    --enable-crypt \
    --enable-rlookups
make depend
make DEFINES="-DSLAP_SCHEMA_EXPOSE"
# Build the contrib modules
make -C contrib/slapd-modules/alias prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/allowed prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/authzid prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/autogroup prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/datamorph prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/dsaschema prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/lastbind prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/noopsrch prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/passwd/pbkdf2 prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/passwd/sha2 prefix=%{_syprefix} libexecdir=%{_sylibdir} OPT=-fno-strict-aliasing
make -C contrib/slapd-modules/ppm prefix=%{_syprefix} libexecdir=%{_sylibdir} etcdir=%{_etcfix} OPT=-fPIC
make -C contrib/slapd-modules/rbac prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/smbk5pwd prefix=%{_syprefix} libexecdir=%{_sylibdir} \
 HEIMDAL_INC='-I%{_syprefix}/include/heimdal' HEIMDAL_LIB='-L%{_sylibdir} -lkrb5 -lkadm5srv' \
 SSL_INC='-I%{_syprefix}/include' SSL_LIB='-L%{_sylibdir} -lcrypto'
make -C contrib/slapd-modules/variant prefix=%{_syprefix} libexecdir=%{_sylibdir}

# For the mdb_* binary commands
pushd libraries/liblmdb
export XCFLAGS="%{optflags}"
make prefix=%{_syprefix}
popd

# Run the test suite
%check

# The initial compilation of real executables by libtool can postpone slapd
# startup and miss the testsuite deadline. Rather than pushing up the SLEEP*
# variables, slowing down the testsuite and hope the host isn't even slower,
# just force libtool's hand and issue a synchronous call now
time ./servers/slapd/slapd -VVV
make test

# Install the software into the RPM buildroot
%install
make install DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/alias install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/allowed install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/authzid install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/autogroup install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/datamorph install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/dsaschema install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/lastbind install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/noopsrch install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/passwd/pbkdf2 install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/passwd/sha2 install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS="" OPT=-fno-strict-aliasing
make -C contrib/slapd-modules/ppm install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS="" etcdir=%{_etcfix}
make -C contrib/slapd-modules/rbac install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/smbk5pwd install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/variant install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""

# For the mdb_* binary commands
pushd libraries/liblmdb
make install prefix=%{_syprefix} DESTDIR=%{buildroot}
popd

# For slapd-watcher
pushd tests/progs
make install prefix=%{_syprefix} DESTDIR=%{buildroot}
popd

# Remove files we do not want distributed in the RPMs
rm -f %{buildroot}%{_syprefix}/include/lmdb.h
rm -f %{buildroot}%{_sylibdir}/liblmdb.a
rm -f %{buildroot}%{_sylibdir}/liblmdb.so
rm -f %{buildroot}%{_sylibdir}/openldap/allowed.a
rm -f %{buildroot}%{_sylibdir}/openldap/autogroup.a
rm -f %{buildroot}%{_sylibdir}/openldap/datamorph.a
rm -f %{buildroot}%{_sylibdir}/openldap/lastbind.a
rm -f %{buildroot}%{_sylibdir}/openldap/noopsrch.a
rm -f %{buildroot}%{_sylibdir}/openldap/ppm.a
rm -f %{buildroot}%{_sylibdir}/openldap/pw-pbkdf2.a
rm -f %{buildroot}%{_sylibdir}/openldap/pw-sha2.a
rm -f %{buildroot}%{_sylibdir}/openldap/rbac.a
rm -f %{buildroot}%{_sylibdir}/openldap/smbk5pwd.a
rm -f %{buildroot}%{_sylibdir}/openldap/variant.a
rm -f %{buildroot}%{_sylibdir}/openldap/authzid.a
rm -f %{buildroot}%{_sylibdir}/openldap/dsaschema.a
rm -f %{buildroot}%{_sylibdir}/openldap/alias.a
rm -f %{buildroot}%{_etcfix}/openldap/ppm.example
rm -f %{buildroot}%{_sylibdir}/*.la
rm -f %{buildroot}%{_unitdir}/slapd.service
chmod 0755 %{buildroot}%{_sylibdir}/lib*.so*
chmod 0644 %{buildroot}%{_sylibdir}/openldap/*.la

# Ensure these empty directories are a part of the resulting RPM buildroot
install -m 0711 -d %{buildroot}%{_varfix}/openldap-data
install -m 0755 -d %{buildroot}%{_varfix}/run

# install an init script for the servers
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}%{_unitdir}/symas-openldap-servers.service
pushd %{buildroot}%{_unitdir}
ln -s symas-openldap-servers.service slapd.service
popd

# Items specific to the moddev package
mkdir -p %{buildroot}%{_syprefix}/bin/moddev
install -m 0755 libtool %{buildroot}%{_syprefix}/bin/moddev/
install -m 0755 build/shtool %{buildroot}%{_syprefix}/bin/moddev/
mkdir -p %{buildroot}%{_syprefix}/include/moddev/ac
mkdir -p %{buildroot}%{_syprefix}/include/moddev/ucdata
mkdir -p %{buildroot}%{_syprefix}/include/moddev/back-monitor
install -m 0644 include/lber_pvt.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_avl.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_cdefs.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_config.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_defaults.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_features.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_int_thread.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_log.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_pvt.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_pvt_thread.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_pvt_uc.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_queue.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/lutil.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/lutil_lockf.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/portable.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_rq.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/rewrite.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/proto-slap.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/slap.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/slap-config.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/back-monitor/back-monitor.h %{buildroot}%{_syprefix}/include/moddev/back-monitor/
install -m 0644 servers/slapd/back-monitor/proto-back-monitor.h %{buildroot}%{_syprefix}/include/moddev/back-monitor/
install -m 0644 include/ac/assert.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/bytes.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/fdset.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/localize.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/param.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/regex.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/signal.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/socket.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/stdlib.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/string.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/syslog.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/time.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/unistd.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/alloca.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/crypt.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/ctype.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/dirent.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/errno.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/stdarg.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/sysexits.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/termios.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/wait.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 libraries/liblunicode/ucdata/ucdata.h %{buildroot}%{_syprefix}/include/moddev/ucdata/
sed -i "s|\.\./libraries/liblunicode/||" %{buildroot}%{_syprefix}/include/moddev/ldap_pvt_uc.h

# GDB helper scripts
mkdir -p %{buildroot}%{_sylibdir}/gdb
install -m 0644 extras/gdb/* %{buildroot}%{_sylibdir}/gdb/

# Additional schema installation
install -m 0644 extras/schema/* %{buildroot}%{_etcfix}/openldap/schema/

# Install the example scripts
mkdir -p %{buildroot}%{_syprefix}/share/symas
install -m 0755 extras/symas/*.sh %{buildroot}%{_syprefix}/share/symas
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}%{_syprefix}/share/symas/exampledb.sh
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}%{_syprefix}/share/symas/exampledb-otp.sh

# Install the profile.d helper scripts that add the Symas locations
# to the user path
mkdir -p %{buildroot}/etc/profile.d
install -m 0644 extras/profile.d/* %{buildroot}/etc/profile.d
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}/etc/profile.d/50-soldap.sh
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}/etc/profile.d/50-soldap.csh

# Install the Symas open source license
mkdir -p %{buildroot}%{_syprefix}/share/doc/symas
install -m 0644 extras/symas/Symas-License.txt %{buildroot}%{_syprefix}/share/doc/symas

# Install OpenLDAP license and other documentation into the doc root
mkdir -p %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 ANNOUNCEMENT %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 CHANGES %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 COPYRIGHT %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 INSTALL %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 LICENSE %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 README %{buildroot}%{_syprefix}/share/doc/openldap



# Files for the libs package
%files libs
%defattr(-,root,root)
%{_etcfix}/openldap/ldap.conf.default
%{_sylibdir}/*.so.*
%{_syprefix}/share/man/man5/ldap.conf.5
%{_syprefix}/share/man/man5/ldif.5
%{_syprefix}/share/doc/openldap
%{_syprefix}/share/doc/symas
/etc/profile.d/50-soldap*

# Files for the devel package
%files devel
%defattr(-,root,root)
%{_syprefix}/include/*.h
%{_sylibdir}/*.a
%{_sylibdir}/*.so
%{_sylibdir}/pkgconfig/*.pc
%{_syprefix}/share/man/man3

# Files for the servers package
%files servers
%defattr(-,root,root)
%{_syprefix}/bin/mdb_*
%{_syprefix}/sbin
%{_etcfix}
%{_sylibdir}/slapd
%{_sylibdir}/openldap
%{_sylibdir}/gdb
%{_syprefix}/share/man/man1/mdb_*
%{_syprefix}/share/man/man5/slap*.5
%{_syprefix}/share/man/man5/lload*.5
%{_syprefix}/share/man/man8
%{_syprefix}/share/symas
%dir %{_varfix}
%dir %{_varfix}/openldap-data/
%dir %{_varfix}/run/
%{_unitdir}/symas-openldap-servers.service
%{_unitdir}/slapd.service
%exclude %{_etcfix}/openldap/ldap.conf
%exclude %{_etcfix}/openldap/ldap.conf.default
%exclude %{_etcfix}/openldap/slapd.conf
%exclude %{_etcfix}/openldap/slapd.ldif
%exclude %{_syprefix}/share/man/man5/ldap.conf.5
%exclude %{_syprefix}/share/man/man5/ldif.5

# Files for the clients package
%files clients
%defattr(-,root,root)
%{_syprefix}/bin
%{_syprefix}/share/man/man1
%exclude %{_syprefix}/bin/mdb_*
%exclude %{_syprefix}/share/man/man1/mdb_*
%exclude %{_syprefix}/bin/moddev

# Files for the moddev package
%files moddev
%{_syprefix}/include/moddev
%{_syprefix}/bin/moddev



# post install commands
%post servers
%systemd_post symas-openldap-servers.service

# pre uninstall commands
%preun servers
%systemd_preun symas-openldap-servers.service

# post uninstall commands
%postun servers
%systemd_postun_with_restart symas-openldap-servers.service

%changelog
* Wed Jun 04 2025 Symas Support <support@symas.com> - 2.6.10-1+znssl1
- Switch to native OpenSSL
* Tue May 27 2025 Symas Support <support@symas.com> - 2.6.10-1
- Release 2.6.10-1
* Wed Mar 05 2025 Symas Support <support@symas.com> - 2.6.9-2
- ITS-10307 Regression when searching for nonexistent entries and no access to DB
* Wed Dec 04 2024 Symas Support <support@symas.com> - 2.6.9-1
- Release 2.6.9-1
* Tue Oct 08 2024 Symas Support <support@symas.com> - 2.6.8-5
- Fixed slapo-nestgroup leak in nestgroup_memberFilter (ITS#10249)
* Thu Jul 11 2024 Symas Support <support@symas.com> - 2.6.8-4
- Patches for Argon2 ITS9827
* Sun Jun 23 2024 Symas Support <support@symas.com> - 2.6.8-3
- Bump version to rebuild with opensuse 15.5
* Thu Jun 20 2024 Symas Support <support@symas.com> - 2.6.8-2
- Re-add run folder management for deb builds
- Enable alias contrib module
- Add patch for memberof ITS-10230
* Wed Jun 05 2024 Symas Support <support@symas.com> - 2.6.8-1
- OpenLDAP 2.6.8 release
- Switch to apkg for packaging
- Cleanup packaging across distros
- Provide module-api/abi virtual packages
- Trim Build-depends
* Mon Feb 19 2024 Symas Support <support@symas.com> - 2.6.7-2
- ITS#9952 TLS/OpenSSL: disable use of atexit()
* Thu Feb 01 2024 Symas Support <support@symas.com> - 2.6.7-1
- OpenLDAP 2.6.7 release
* Tue Oct 31 2023 Symas Support <support@symas.com> - 2.6.6-3
- OpenLDAP 2.6.6-3 with openssl3
* Thu Aug 03 2023 Symas Support <support@symas.com> - 2.6.6-1
- OpenLDAP 2.6.6 release
- Changing back to openssl 1.1.1
* Tue Jul 11 2023 Symas Support <support@symas.com> - 2.6.5-1
- OpenLDAP 2.6.5 release
* Wed May 31 2023 Symas Support <support@symas.com> - 2.6.5~rc1-2
- OpenLDAP 2.6.5~rc1-2 with Openssl3 release candidate build
* Fri May 26 2023 Symas Support <support@symas.com> - 2.6.5~rc1-1
- OpenLDAP 2.6.5~rc1 release candidate build
* Wed Feb 08 2023 Symas Support <support@symas.com> - 2.6.4-1
- OpenLDAP 2.6.4 release
* Tue Jan 31 2023 Symas Support <support@symas.com> - 2.6.4~rc3-1
- OpenLDAP 2.6.4~rc3 release candidate build
* Thu Jan 19 2023 Symas Support <support@symas.com> - 2.6.4~rc2-1
- OpenLDAP 2.6.4~rc2 release candidate build
* Wed Oct 05 2022 Symas Support <support@symas.com> - 2.6.4~rc1-1
- OpenLDAP 2.6.4~rc1 release candidate build
- Added authzid contrib module
* Mon Jul 18 2022 Symas Support <support@symas.com> - 2.6.3-1
- OpenLDAP 2.6.3 release
* Wed Jul 13 2022 Symas Support <support@symas.com> - 2.6.3~rc2-1
- OpenLDAP 2.6.3~rc2 release candidate build
* Thu Jul 07 2022 Symas Support <support@symas.com> - 2.6.3~rc1-1
- OpenLDAP 2.6.3~rc1 release candidate build
* Tue May 10 2022 Symas Support <support@symas.com> - 2.6.2-1
- OpenLDAP 2.6.2 release
* Thu Mar 24 2022 15:28:22 Symas Support <support@symas.com> - 2.6.2-0rc1
- OpenLDAP 2.6.2-0rc1 release candidate
* Thu Jan 27 2022 Symas Support <support@symas.com> - 2.6.1-2
- ITS9787 patch fix
* Fri Jan 21 2022 Symas Support <support@symas.com> - 2.6.1-1
- OpenLDAP 2.6.1 release
* Wed Jan 05 2022 Symas Support <support@symas.com> - 2.6.0-6
- Enable dynacl support
- Update moddev package with additional headers necessary for dynacl builds
* Mon Dec 13 2021 Symas Support <support@symas.com> - 2.6.0-5
- Package slapo-allowed contrib module
- ITS9756 patch fix
* Wed Dec 01 2021 Symas Support <support@symas.com> - 2.6.0-4
- ITS9747 patch fix
- ITS9752 patch fix
- ITS9753 patch fix
- ITS9725 patch fix
* Tue Nov 16 2021 Symas Support <support@symas.com> - 2.6.0-3
- ITS9745 patch fix
- Package ANNOUNCEMENT, CHANGES, COPYRIGHT, INSTALL, LICENSE, and README files
* Fri Oct 29 2021 Symas Support <support@symas.com> - 2.6.0-2
- ITS9730 patch fix
* Tue Oct 26 2021 Symas Support <support@symas.com> - 2.6.0-1
- OpenLDAP 2.6.0 release
- ITS9715 patch fix
